/* This example demonstrates how to use the KEYBLOCK clause
   and DCBROWSE to drop down a list of
   valid names and scope the list based on the characters
   entered.  If names are in a database, use dbSeek() and
   DC_SetScope() in place of Ascan(). */


#INCLUDE "dcdialog.CH"
#INCLUDE "appevent.CH"

FUNCTION Main()

LOCAL GetList[0], cName, aNames[0], cPerformer, oBrowse, oPerformer, nWhich := 1

DC_LoadRdds()
USE PERFORMERS INDEX PERFORMERS VIA 'FOXCDX'

cPerformer := Space(30)

@ 0,0 DCSAY 'Enter Performer Name' GET cPerformer ;
      SAYSIZE 0 SAYBOTTOM ;
      GETOBJECT oPerformer ;
      KEYBLOCK {|a,b,o|DropDownNames(a,o,@cPerformer,aNames,oBrowse,nWhich), ;
                       DC_BrowseAutoSeek(a,o,oBrowse,aNames)}

@ 2,0 DCRADIO nWhich PROMPT 'Get names from Database' VALUE 1
@ DCGUI_ROW, DCGUI_COL + 10 DCRADIO nWhich PROMPT 'Get names from Array' VALUE 2

@ 1,16 DCBROWSE oBrowse DATA aNames SIZE 35,10 ;
       FONT '10.Lucida Console' ;
       FILTER {|a|a[2]} ;
       ITEMSELECTED {|a,b,o|IIF(o:isVisible(), ;
                       (cPerformer := Pad(aNames[oBrowse:arrayElement,1],30), ;
                        oPerformer:setData(cPerFormer),o:hide()),nil)} ;
       LOSTFOCUS {|a,b,o|o:hide()} ;
       NOHSCROLL ;
       USEVISUALSTYLE

DCBROWSECOL ELEMENT 1 WIDTH 30 PARENT oBrowse

DCREAD GUI FIT TITLE 'Scoped Drop-Down' EVAL {||oBrowse:hide()}

RETURN nil

* -----------

PROC appsys ; RETURN

* -----------

STATIC FUNCTION DropDownNames( nKey, oGet, cPerformer, aNames, oBrowse, nWhich )

LOCAL i, nFound := 0, cName, nLen, nNames, aNames2

IF (Chr(nKey) < 'A' .OR. Chr(nKey) > 'z') .AND. !nKey $ {xbeK_SPACE,xbeK_BS}
  RETURN nil
ENDIF

oGet:getData()

cName := Alltrim(Upper(cPerformer))
nLen := Len(cName)

ASize(aNames,0)

IF nWhich = 2
  aNames2 := PerformerNames()
  nNames := Len(aNames2)
  FOR i := 1 TO nNames
    IF Upper(Left(aNames2[i],nLen)) == cName
      AAdd(aNames,{ aNames2[i],.t. } )
    ENDIF
  NEXT
ELSE
  PERFORMERS->(DC_SetScope(0,cName))
  PERFORMERS->(DC_SetScope(1,cName))
  PERFORMERS->(dbGoTop())
  DO WHILE !PERFORMERS->(Eof())
    AAdd( aNames, { PERFORMERS->performer,.t. } )
    PERFORMERS->(dbSkip())
  ENDDO
  nFound := Len(aNames)
ENDIF

oBrowse:goTop()
oBrowse:forceStable()
oBrowse:refreshAll()

IF Len(aNames) > 0 .AND. !Empty(cName)
  oBrowse:show()
ELSE
  oBrowse:hide()
ENDIF

RETURN nil

* ------------

STATIC FUNCTION PerformerNames()

LOCAL aNames, i

aNames := { ;
   'Annie Hall', ;
   'Arlo Guthrie', ;
   'Bette Midler', ;
   'Bob Dylan', ;
   'Bobbie Gentry', ;
   'Buddy Holly', ;
   'Canned Heat', ;
   'Carol Elliot', ;
   'Carole King', ;
   'Caroline Aikin', ;
   'Cat Stevens', ;
   'Catie Curtis', ;
   'Cheryl Wheeler', ;
   'Chuck Prophet', ;
   'Chuck Pyle', ;
   'Crosby, Stills, Nash', ;
   'Danny Kaye', ;
   'Dar Williams', ;
   'Dr Hook', ;
   'Eliza Gilkyson', ;
   'Elton John', ;
   'Elvis Presley', ;
   'Freddie Mercury', ;
   'Gail Davies', ;
   'Glenn Miller', ;
   'Gordon Rowland', ;
   'Greg Brown', ;
   'Harry McClintock', ;
   'Itzhak Perlman', ;
   'James Taylor', ;
   'Jan Stanfield', ;
   'Jefferson Airplane', ;
   'Jim Croce', ;
   'Jimi Hendrix', ;
   'Jimmy Dean', ;
   'John Denver', ;
   'Joni Mitchell', ;
   'Journey', ;
   'Kevin Welch', ;
   'Krystian Zimermann', ;
   'Led Zeppelin', ;
   'Lyle Lovett', ;
   'Lynn Miles', ;
   'Madeleine Peyroux', ;
   'Michael Jackson', ;
   'Michael Lille', ;
   'Mumbo Gumbo', ;
   'Norah Jones', ;
   'Ray Charles', ;
   'Richard Pryor', ;
   'Richard Shindell', ;
   'Richie Havens', ;
   'Robin Williams', ;
   'Roy Orbison', ;
   'Sam Cooke', ;
   'Slobberbone', ;
   'Steppenwolf', ;
   'Susan Werner', ;
   'Ten Years After', ;
   'The Beatles', ;
   'The Doors', ;
   'The Eagles', ;
   'The Flatlanders', ;
   'The Moody Blues', ;
   'Tim Bays', ;
   'Toby Keith', ;
   'Tom Paxton', ;
   'Tom Petty', ;
   'Tom Prasada-Rao', ;
   'Van Morrison', ;
   'Vance Gilbert', ;
   'Vic Chestnutt', ;
   'Willie Nelson', ;
   'Yo-yo Ma', ;
   'Yundi Li'}

RETURN aNames
